function [H, W] = dtft_n0(h, n0, N)
%DTFT   calculate DTFT at N equally spaced frequencies with time shift (n0)
%----
%   Usage:   [H, W] = dtft_n0(h, n0, N)
%
%      h  : finite-length input vector, whose length is L
%      n0 : signal starting index
%      N  : number of frequencies for evaluation over [-pi,pi)
%              ==> constraint: N >= L 
%      H  : DTFT values (complex)
%      W  : (2nd output) vector of freqs where DTFT is computed

%---------------------------------------------------------------
% copyright 1994, by C.S. Burrus, J.H. McClellan, A.V. Oppenheim,
% T.W. Parks, R.W. Schafer, & H.W. Schussler.  For use with the book
% "Computer-Based Exercises for Signal Processing Using MATLAB"
% (Prentice-Hall, 1994).
%---------------------------------------------------------------

N = fix(N);
L = length(h);  h = h(:);  %<-- for vectors ONLY !!!
if( N < L )
   error('DTFT: # data samples cannot exceed # freq samples')
end
W = (2*pi/N) * [ 0:(N-1) ]';
mid = ceil(N/2) + 1;
W(mid:N) = W(mid:N) - 2*pi;   % <--- move [pi,2pi) to [-pi,0)
W = fftshift(W);
F = fftshift( fft( h, N ) );  %<--- move negative freq components

% Multiply FFT result by exp(-jwn0) for time shift
enn = 0:(N-1);
ee = exp(1j*(n0*enn*2*pi/N));
H = F .* ee';

